@@ -7,7 +7,7 @@ test_description='Branch cleanup'
 test_expect_success 'Initialize branch' '
     stg init &&
     stg branch --create foo &&
-    echo "hello" > bar &&
+    echo "hello" >bar &&
     stg add bar &&
     stg new -m p0 &&
     stg refresh
@@ -15,13 +15,13 @@ test_expect_success 'Initialize branch' '
 
 test_expect_success 'Cannot cleanup with patches' '
     command_error stg branch --cleanup 2>err &&
-    grep "Cannot clean up: the series still contains patches" err
+    grep "Clean up not permitted: the series still contains patches" err
 '
 
 test_expect_success 'Cannot cleanup with unapplied patches' '
     stg pop &&
     command_error stg branch --cleanup 2>err &&
-    grep "Cannot clean up: the series still contains patches" err
+    grep "Clean up not permitted: the series still contains patches" err
 '
 
 test_expect_success 'Clone branch with patches' '
@@ -34,9 +34,10 @@ test_expect_success 'Force cleanup branch with patches' '
     git config --get-regexp branch\\.foo2\\.stgit &&
     stg branch --cleanup --force &&
     test "$(stg series --noprefix --all)" = "" &&
-    command_error stg new -m p1 2>err &&
-    grep "branch not initialized" err &&
-    test_expect_code 1 git config --get-regexp branch\\.foo2\\.stgit
+    command_error stg branch --cleanup 2>err &&
+    grep "StGit stack not initialized for branch \`foo2\`" err &&
+    test_expect_code 1 git config --get-regexp branch\\.foo2\\.stgit &&
+    test_expect_code 128 git config --remove-section branch.foo2.stgit
 '
 
 test_expect_success 'Commit patches' '
@@ -46,15 +47,15 @@ test_expect_success 'Commit patches' '
 '
 
 test_expect_success 'Invalid num args to cleanup' '
-    command_error stg branch --cleanup foo extra 2>err &&
-    grep "incorrect number of arguments" err
+    general_error stg branch --cleanup foo extra 2>err &&
+    grep "Found argument .extra. which wasn.t expected" err
 '
 
 test_expect_success 'Cleanup current branch' '
     stg branch --cleanup &&
     test "$(stg branch)" = "foo" &&
-    command_error stg new -m p1 2>err &&
-    grep "branch not initialized" err
+    command_error stg branch --cleanup 2>err &&
+    grep "StGit stack not initialized for branch \`foo\`" err
 '
 
 test_expect_success 'Re-initialize branch' '
