@@ -5,8 +5,7 @@ test_description='Test "stg push" with hidden patches'
 . ./test-lib.sh
 
 test_expect_success 'Initialize StGit stack' '
-    stg init &&
-    echo foo > foo.txt &&
+    echo foo >foo.txt &&
     stg add foo.txt &&
     stg new -m hidden-patch &&
     stg refresh &&
@@ -20,9 +19,10 @@ test_expect_success 'Push an implicitly named hidden patch (should fail)' '
     test "$(echo $(stg series --all))" = "! hidden-patch"
 '
 
-test_expect_failure 'Push an explicitly named hidden patch (should work)' '
-    stg push hidden-patch &&
-    test "$(echo $(stg series --all))" = "> hidden-patch"
+test_expect_success 'Push an explicitly named hidden patch (should fail)' '
+    command_error stg push hidden-patch 2>err &&
+    test "$(echo $(stg series --all))" = "! hidden-patch" &&
+    grep "error: Hidden patch \`hidden-patch\` is not allowed" err
 '
 
 test_done
