@@ -1,9 +1,15 @@
 #!/bin/sh
+
 test_description='Test stg commit'
+
 . ./test-lib.sh
 
+test_expect_success 'Attempt commit on uninitialized branch' '
+    command_error stg commit --all 2>err &&
+    grep "error: No patches applied" err
+'
+
 test_expect_success 'Initialize the StGit repository' '
-    stg init &&
     stg new -m p1 &&
     stg new -m p2 &&
     stg new -m p3 &&
@@ -13,7 +19,7 @@ test_expect_success 'Initialize the StGit repository' '
 
 test_expect_success 'Attempt to commit an empty patch' '
     command_error stg commit p2 2>err &&
-    grep "Empty patch" err
+    grep "Attempt to commit empty patch \`p2\`" err
 '
 
 test_expect_success 'Commit middle patch' '
@@ -33,7 +39,7 @@ test_expect_success 'Commit all patches' '
 '
 
 # stg commit with top != head should not succeed, since the committed
-# patches are poptentially lost.
+# patches are potentially lost.
 test_expect_success 'Commit when top != head (should fail)' '
     stg new -m foo &&
     git reset --hard HEAD^ &&
