@@ -1,25 +1,29 @@
 #!/bin/sh
-#
+
 # Copyright (c) 2006 Ilpo Järvinen
-#
 
 test_description='Test "stg goto"'
 
 . ./test-lib.sh
 
+test_expect_success 'Attempt goto with uninitialized stack' '
+    command_error stg goto foo 2>err &&
+    grep "error: Patch \`foo\` does not exist" err &&
+    rm err
+'
+
 test_expect_success 'Initialize stgit repository' '
-    stg init &&
     for i in 1 2 3 4 5; do
         stg new p$i -m "patch $i" &&
-        echo $i > file$i &&
+        echo $i >file$i &&
         stg add file$i &&
         stg refresh
     done
 '
 
 test_expect_success 'Test invalid number of arguments' '
-    command_error stg goto 2>err &&
-    grep -e "incorrect number of arguments" err
+    general_error stg goto 2>err &&
+    grep -e "error: The following required arguments were not provided:" err
 '
 
 test_expect_success 'Goto current patch' '
@@ -29,12 +33,12 @@ test_expect_success 'Goto current patch' '
 
 test_expect_success 'Attempt goto invalid patch' '
     command_error stg goto p999 2>err &&
-    grep -e "Patch \"p999\" does not exist" err
+    grep -e "Patch \`p999\` does not exist" err
 '
 
 test_expect_success 'Attempt goto invalid hash' '
     command_error stg goto beeff00d 2>err &&
-    grep -e "No patch associated with beeff00d" err
+    grep -e "error: No patch associated with \`beeff00d\`" err
 '
 
 test_expect_success 'Goto a patch' '
@@ -55,7 +59,7 @@ test_expect_success 'Refuse to go to a hidden patch' '
     stg new h0 -m "hidden patch" &&
     stg hide h0 &&
     command_error stg goto h0 2>err &&
-    grep -e "Cannot goto a hidden patch" err &&
+    grep -e "Hidden patch \`h0\` is not allowed" err &&
     test "$(echo $(stg series --hidden --noprefix))" = "h0" &&
     test "$(echo $(stg series --applied --noprefix))" = "p1 p2 p3" &&
     test "$(echo $(stg series --unapplied --noprefix))" = "p4 p5"
@@ -68,9 +72,10 @@ test_expect_success 'Goto with merge check' '
 '
 
 test_expect_success 'Goto with ambiguous patch substring' '
-    stg goto 1 &&
+    command_error stg goto 1 2>err &&
+    grep "error: Patch \`1\` does not exist" err &&
     command_error stg goto p 2>err &&
-    grep "Ambiguous patch name \"p\"" err
+    grep "Patch \`p\` does not exist, but is similar to \`p1\`, \`p2\`" err
 '
 
 test_done
