@@ -4,21 +4,17 @@ test_description='test rebase --interactive'
 
 . ./test-lib.sh
 
-
 test_expect_success 'Initialize StGit stack' '
-    stg init &&
     stg new p0 -m p0 &&
     stg new p1 -m p1 &&
     stg new p2 -m p2 &&
     stg new p3 -m p3
 '
 
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
+test_expect_success 'Apply patches with APPLY_LINE' '
+    write_script fake-editor <<-\EOF &&
 	printf "keep p0\nkeep p1\n# --- APPLY_LINE ---\nkeep p2\nkeep p3\n" >"$1"
 	EOF
-'
-test_expect_success 'Apply patches with APPLY_LINE' '
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -26,24 +22,20 @@ test_expect_success 'Apply patches with APPLY_LINE' '
     git diff-index --quiet HEAD
 '
 
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
+test_expect_success 'Bad APPLY_LINE throws an error' '
+    write_script fake-editor <<-\EOF &&
 	printf "# --- APPLY_LINE ---this_text_does_not_belong\n" >"$1"
 	EOF
-'
-test_expect_success 'Bad APPLY_LINE throws an error' '
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     command_error stg rebase --interactive 2>err &&
     grep -e "Bad APPLY_LINE" err
 '
 
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
+test_expect_success 'Apply patches without APPLY_LINE' '
+    write_script fake-editor <<-\EOF &&
 	printf "keep p0\nkeep p1\n" >"$1"
 	EOF
-'
-test_expect_success 'Apply patches without APPLY_LINE' '
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -51,51 +43,41 @@ test_expect_success 'Apply patches without APPLY_LINE' '
     git diff-index --quiet HEAD
 '
 
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
+test_expect_success 'Bad todo line throws error' '
+    write_script fake-editor <<-\EOF &&
 	printf "keep\n" >"$1"
 	EOF
-'
-test_expect_success 'Bad todo line throws error' '
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     command_error stg rebase --interactive 2>err &&
-    grep -e "Bad todo line" err
+    grep -e "Bad instruction line: \`keep\`" err
 '
 
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
+test_expect_success 'Bad patch name throws error' '
+    write_script fake-editor <<-\EOF &&
 	printf "keep invalid_patch_name\n" >"$1"
 	EOF
-'
-test_expect_success 'Bad patch name throws error' '
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     command_error stg rebase --interactive 2>err &&
-    grep -e "Bad patch name" err
+    grep -e "Unknown patch name \`invalid_patch_name\`" err
 '
 
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
+test_expect_success 'Bad instruction throws error' '
+    write_script fake-editor <<-\EOF &&
 	printf "invalid_instruction p1\n" >"$1"
 	EOF
-'
-test_expect_success 'Bad instruction throws error' '
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     command_error stg rebase --interactive 2>err &&
     grep -e "Unknown instruction" err
 '
 
-test_expect_success 'Setup stgit stack' '
-    stg new pHidden -m pHidden
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\eof
-	printf "hide pHidden\n" >"$1"
-	eof
-'
 test_expect_success 'Hide a patch' '
+    stg new pHidden -m pHidden &&
+    write_script fake-editor <<-\EOF &&
+	printf "hide pHidden\n" >"$1"
+	EOF
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -104,15 +86,11 @@ test_expect_success 'Hide a patch' '
     git diff-index --quiet HEAD
 '
 
-test_expect_success 'Setup stgit stack' '
-    stg new p4 -m p4
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\eof
-	printf "delete p4\n" >"$1"
-	eof
-'
 test_expect_success 'Delete a patch' '
+    stg new p4 -m p4 &&
+    write_script fake-editor <<-\EOF &&
+	printf "delete p4\n" >"$1"
+	EOF
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -120,15 +98,11 @@ test_expect_success 'Delete a patch' '
     git diff-index --quiet HEAD
 '
 
-test_expect_success 'Setup stgit stack' '
-    stg new p4 -m p4
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\eof
-	printf "edit p4\n" >"$1"
-	eof
-'
 test_expect_success 'Edit a patch' '
+    stg new p4 -m p4 &&
+    write_script fake-editor <<-\EOF &&
+	printf "edit p4\n" >"$1"
+	EOF
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -136,22 +110,18 @@ test_expect_success 'Edit a patch' '
     stg show | grep -e "edit p4"
 '
 
-test_expect_success 'Setup stgit stack' '
-    stg delete --top &&
-    stg new p4 -m p4
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\eof
-    if [ ! -f .fake-editor-has-run-once ]
-    then
-        printf "edit p4\n" >"$1" &&
-        touch .fake-editor-has-run-once
-    else
-        sed "s/Patch: p4/Patch: p4-new/" "$1" > "$1".tmp && mv "$1".tmp "$1"
-    fi
-	eof
-'
 test_expect_success 'Edit and rename a patch' '
+    stg delete --top &&
+    stg new p4 -m p4 &&
+    write_script fake-editor <<-\EOF &&
+	if [ ! -f .fake-editor-has-run-once ]
+	then
+	    printf "edit p4\n" >"$1" &&
+	    touch .fake-editor-has-run-once
+	else
+	    sed "s/Patch: *p4/Patch: p4-new/" "$1" >"$1".tmp && mv "$1".tmp "$1"
+	fi
+	EOF
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -161,18 +131,16 @@ test_expect_success 'Edit and rename a patch' '
 rm .fake-editor-has-run-once
 
 
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\eof
-    if [ ! -f .fake-editor-has-run-once ]
-    then
-        printf "edit p4-new\n" >"$1" &&
-        touch .fake-editor-has-run-once
-    else
-        sed "s/Patch: p4-new/Patch:/" "$1" > "$1".tmp && mv "$1".tmp "$1"
-    fi
-	eof
-'
 test_expect_success 'Edit a patch and clear its patchname' '
+    write_script fake-editor <<-\EOF &&
+	if [ ! -f .fake-editor-has-run-once ]
+	then
+	    printf "edit p4-new\n" >"$1" &&
+	    touch .fake-editor-has-run-once
+	else
+	    sed "s/Patch: p4-new/Patch:/" "$1" >"$1".tmp && mv "$1".tmp "$1"
+	fi
+	EOF
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -181,19 +149,15 @@ test_expect_success 'Edit a patch and clear its patchname' '
 '
 rm .fake-editor-has-run-once
 
-test_expect_success 'Setup stgit stack' '
+test_expect_success 'Delete two patches and the correct two are deleted' '
     stg delete $(stg series --all --noprefix --no-description) &&
     stg new -m p0 &&
     stg new -m p1 &&
     stg new -m p2 &&
-    stg new -m p3
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\eof
+    stg new -m p3 &&
+    write_script fake-editor <<-\EOF &&
 	printf "delete p0\ndelete p2\n" >"$1"
-	eof
-'
-test_expect_success 'Delete two patches and the correct two are deleted' '
+	EOF
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -201,36 +165,28 @@ test_expect_success 'Delete two patches and the correct two are deleted' '
     git diff-index --quiet HEAD
 '
 
-test_expect_success 'Setup stgit stack' '
-    stg delete $(stg series --all --noprefix --no-description) &&
-    stg new -m p0 &&
-    stg new -m p1
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
-	printf "keep p0\nsquash p1\n" >"$1"
-	EOF
-'
 test_expect_success 'Squash succeeds' '
-    test_set_editor "$(pwd)/fake-editor" &&
-    test_when_finished test_set_editor false &&
-    stg rebase --interactive &&
-    git diff-index --quiet HEAD &&
-    test "$(stg series -c)" = "1"
-'
-
-test_expect_success 'Setup stgit stack' '
     stg delete $(stg series --all --noprefix --no-description) &&
     stg new -m p0 &&
     stg new -m p1 &&
-    stg new -m p2
+    write_script fake-editor <<-\EOF &&
+	printf "keep p0\nsquash p1\n" >"$1"
+	EOF
+    test_set_editor "$(pwd)/fake-editor" &&
+    test_when_finished test_set_editor false &&
+    stg rebase --interactive &&
+    git diff-index --quiet HEAD &&
+    test "$(stg series -c)" = "1"
 '
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
+
+test_expect_success 'Squash on a Squash succeeds' '
+    stg delete $(stg series --all --noprefix --no-description) &&
+    stg new -m p0 &&
+    stg new -m p1 &&
+    stg new -m p2 &&
+    write_script fake-editor <<-\EOF &&
 	printf "keep p0\nsquash p1\nsquash p2\n" >"$1"
 	EOF
-'
-test_expect_success 'Squash on a Squash succeeds' '
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -238,35 +194,26 @@ test_expect_success 'Squash on a Squash succeeds' '
     test "$(stg series -c)" = "1"
 '
 
-test_expect_success 'Setup stgit stack' '
+test_expect_success 'Fix on first patch does not crash' '
     stg delete $(stg series --all --noprefix --no-description) &&
     stg new -m p0 &&
-    stg new -m p1
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
+    stg new -m p1 &&
+    write_script fake-editor <<-\EOF &&
 	printf "fix p0\nfix p1\n" >"$1"
 	EOF
-'
-test_expect_success 'Fix on first patch does not crash' '
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
-    stg rebase --interactive &&
-    git diff-index --quiet HEAD &&
-    test "$(stg series -c)" = "1"
+    command_error stg rebase --interactive 2>err &&
+    grep -e "Cannot fixup \`p0\`: no preceding patch" err
 '
 
-test_expect_success 'Setup stgit stack' '
+test_expect_success 'Fix succeeds' '
     stg delete $(stg series --all --noprefix --no-description) &&
     stg new -m p0 &&
-    stg new -m p1
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
+    stg new -m p1 &&
+    write_script fake-editor <<-\EOF &&
 	printf "keep p0\nfix p1\n" >"$1"
 	EOF
-'
-test_expect_success 'Fix succeeds' '
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -274,21 +221,17 @@ test_expect_success 'Fix succeeds' '
     test "$(stg series -c)" = "1"
 '
 
-test_expect_success 'Setup stgit stack' '
+test_expect_success 'Two independent squash chains succeed' '
     stg delete $(stg series --all --noprefix --no-description) &&
     stg new -m p0 &&
     stg new -m p1 &&
     stg new -m p2 &&
     stg new -m p3 &&
     stg new -m p4 &&
-    stg new -m p5
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\EOF
+    stg new -m p5 &&
+    write_script fake-editor <<-\EOF &&
 	printf "keep p0\nsquash p1\nsquash p2\nkeep p3\nsquash p4\nkeep p5\n" >"$1"
 	EOF
-'
-test_expect_success 'Two independent squash chains succeed' '
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -296,39 +239,31 @@ test_expect_success 'Two independent squash chains succeed' '
     test "$(stg series -c)" = "3"
 '
 
-test_expect_success 'Setup stgit stack' '
+test_expect_success 'Delete after squash after delete works correctly' '
     stg delete $(stg series --all --noprefix --no-description) &&
     stg new -m p0 &&
     stg new -m p1 &&
     stg new -m p2 &&
     stg new -m p3 &&
-    stg new -m p4
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\eof
+    stg new -m p4 &&
+    write_script fake-editor <<-\EOF &&
 	printf "keep p0\ndelete p1\nsquash p2\ndelete p3" >"$1"
-	eof
-'
-test_expect_success 'Delete after squash after delete works correctly' '
+	EOF
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
-    test "$(echo $(stg series --noprefix))" = "keep-p0 p4" &&
+    test "$(echo $(stg series --noprefix))" = "p0 p4" &&
     git diff-index --quiet HEAD
 '
 
-test_expect_success 'Setup stgit stack' '
+test_expect_success 'Fixup after hide works correctly' '
     stg delete $(stg series --all --noprefix --no-description) &&
     stg new -m p0 &&
     stg new -m p1 &&
-    stg new -m p2
-'
-test_expect_success 'Setup fake editor' '
-	write_script fake-editor <<-\eof
+    stg new -m p2 &&
+    write_script fake-editor <<-\EOF &&
 	printf "keep p0\nhide p1\nfixup p2" >"$1"
-	eof
-'
-test_expect_success 'Fixup after hide works correctly' '
+	EOF
     test_set_editor "$(pwd)/fake-editor" &&
     test_when_finished test_set_editor false &&
     stg rebase --interactive &&
@@ -342,5 +277,4 @@ test_expect_success 'No patches exits early' '
     stg rebase --interactive
 '
 
-
 test_done
