@@ -1,20 +1,23 @@
 #!/bin/sh
-#
+
 # Copyright (c) 2008 Onno Kortmann
-# Parts taken from the other test scripts
-# in this directory.
-#
+# Parts taken from the other test scripts in this directory.
 
 test_description='stg rename test
 
 Tests some parts of the stg rename command.'
 
 . ./test-lib.sh
-stg init
+
+test_expect_success 'Attempt rename without stack' '
+    command_error stg rename foo 2>err &&
+    grep -e "error: No patches applied" err
+'
 
 test_expect_success 'Rename in empty' '
+   stg init &&
    command_error stg rename foo 2>err &&
-   grep -e "No applied top patch to rename exists" err
+   grep -e "No patches applied" err
 '
 
 test_expect_success 'Rename single top-most' '
@@ -34,18 +37,18 @@ test_expect_success 'Rename with two arguments' '
 # foo,baz
 
 test_expect_success 'Rename with too many arguments' '
-   command_error stg rename foo bar baz 2>err &&
-   grep -e "incorrect number of arguments" err
+   general_error stg rename foo bar baz 2>err &&
+   grep -e "The value .baz. was provided to .<patches>\.\.\.. but it wasn.t expecting any more values" err
 '
 
 test_expect_success 'Rename to existing name' '
    command_error stg rename foo baz 2>err &&
-   grep -e "Patch already exists: \"baz\"" err
+   grep -e "Patch \`baz\` already exists" err
 '
 
 test_expect_success 'Rename to same name' '
    command_error stg rename foo foo 2>err &&
-   grep -e "New patch name same as old: \"foo\"" err
+   grep -e "Patch \`foo\` already exists" err
 '
 
 test_expect_success 'Rename top-most when others exist' '
@@ -53,18 +56,13 @@ test_expect_success 'Rename top-most when others exist' '
 '
 
 test_expect_success 'Rename to invalid patch name: space' '
-   command_error stg rename bar "bar fo" 2>err &&
-   grep -e "Invalid patch name: \"bar fo\"" err
+   general_error stg rename bar "bar fo" 2>err &&
+   grep -e "Invalid patch name \`bar fo\`" err
 '
 
 test_expect_success 'Rename to invalid patch name: colon' '
-   command_error stg rename bar "bar:fo" 2>err &&
-   grep -e "Invalid patch name: \"bar:fo\"" err
-'
-
-test_expect_failure 'Rename to patch name with slash' '
-   stg rename bar bar/fo &&
-   stg rename bar/fo bar
+   general_error stg rename bar "bar:fo" 2>err &&
+   grep -e "Invalid patch name \`bar:fo\`" err
 '
 
 test_expect_success 'Rename hidden' '
