@@ -1,39 +1,44 @@
 #!/bin/sh
 
-test_description='Test the fold command.'
+test_description='Test the fold command'
 
 . ./test-lib.sh
 
+test_expect_success 'Attempt fold on uninitialized stack' '
+    command_error stg fold 2>err &&
+    grep "error: No patches applied" err &&
+    rm err
+'
+
 test_expect_success 'Initialize StGit repository' '
-    stg init &&
-    echo hello > foo.txt &&
+    echo hello >foo.txt &&
     git add foo.txt &&
     git commit -m "add foo.txt" &&
-    echo "preface" > foo.txt &&
-    echo "hello" >> foo.txt &&
-    git diff > threeway.diff &&
+    echo "preface" >foo.txt &&
+    echo "hello" >>foo.txt &&
+    git diff >threeway.diff &&
     git checkout foo.txt &&
     stg new -m p1 &&
-    echo "hello" > foo.txt &&
-    echo "from p1" >> foo.txt &&
+    echo "hello" >foo.txt &&
+    echo "from p1" >>foo.txt &&
     stg refresh &&
-    echo "hello" > foo.txt &&
-    echo "from p1" >> foo.txt &&
-    echo "and fold1" >> foo.txt &&
-    git diff > fold1.diff &&
+    echo "hello" >foo.txt &&
+    echo "from p1" >>foo.txt &&
+    echo "and fold1" >>foo.txt &&
+    git diff >fold1.diff &&
     git checkout foo.txt
 '
 
 test_expect_success 'Attempt fold more than one patch' '
-    command_error stg fold fold1.diff fold2.diff 2>err &&
-    grep -e "incorrect number of arguments" err
+    general_error stg fold fold1.diff fold2.diff 2>err &&
+    grep -e "Found argument .fold2\.diff. which wasn.t expected" err
 '
 
 test_expect_success 'Attempt fold with local changes' '
-    echo "hello dirty" > foo.txt &&
+    echo "hello dirty" >foo.txt &&
     test_when_finished "stg reset --hard" &&
     command_error stg fold fold1.diff 2>err &&
-    grep -e "local changes in the tree" err
+    grep -e "Worktree not clean" err
 '
 
 test_expect_success 'Attempt fold with non-existant patch file' '
@@ -72,8 +77,8 @@ test_expect_success 'Threeway fold' '
 test_expect_success 'Attempt to fold conflicting patch' '
     stg new -m p2 &&
     test_when_finished "stg delete p2" &&
-    echo "hello" > foo.txt &&
-    echo "from p2" >> foo.txt &&
+    echo "hello" >foo.txt &&
+    echo "from p2" >>foo.txt &&
     stg refresh &&
     command_error stg fold fold1.diff 2>err &&
     grep "Patch does not apply cleanly" err &&
@@ -83,11 +88,11 @@ test_expect_success 'Attempt to fold conflicting patch' '
 
 test_expect_success 'Attempt to fold conflicting patch with rejects' '
     stg new -m p2 &&
-    echo "hello" > foo.txt &&
-    echo "from p2" >> foo.txt &&
+    echo "hello" >foo.txt &&
+    echo "from p2" >>foo.txt &&
     stg refresh &&
     command_error stg fold --reject fold1.diff 2>err &&
-    grep "Patch does not apply cleanly" err &&
+    grep "patch failed" err &&
     test -z "$(echo $(stg status --porcelain foo.txt))" &&
     test -e foo.txt.rej &&
     rm foo.txt.rej
